@@ -6,7 +6,15 @@ pub fn add_1()
 {
     unsafe {
         N += 1;
-        println!("N: {}", N);
+        println!("log 0.5.0  N: {}", N);
+    }
+}
+
+pub fn add_2()
+{
+    unsafe {
+        N += 2;
+        println!("log 0.5.0  N: {}", N);
     }
 }
 
@@ -14,6 +22,6 @@ pub fn sub_1()
 {
     unsafe {
         N -= 1;
-        println!("N: {}", N);
+        println!("log 0.5.0  N: {}", N);
     }
 }
\ No newline at end of file
